import {customElement} from 'lit/decorators.js';
import {BaseSearchElement} from '../BaseSearchElement';

/**
 * A container that only displays its children when the search returns no results.
 */
@customElement('search-no-results-message')
export class SearchNoResultsMessage extends BaseSearchElement {
  override connectedCallback() {
    super.connectedCallback();
    this.style.setProperty('display', 'none');
  }

  override render() {
    if (!this.context?.response) {
      return null;
    }

    const results = this.context?.response?.search_results_count;

    if (results) {
      this.style.setProperty('display', 'none');
    } else {
      this.style.removeProperty('display');
    }

    return '';
  }
}

declare global {
  interface HTMLElementTagNameMap {
    'search-no-results-message': SearchNoResultsMessage;
  }
}
