<?php

declare(strict_types = 1);

namespace Drupal\search_web_components_block\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Defines a base facet block implementation that facet plugins can extend.
 *
 * This abstract class provides the generic block configuration form and default
 * facet settings included in the build method.
 */
abstract class FacetBlockBase extends BlockBase {

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration(): array {
    return [
      'key' => '',
      'overrideLabel' => '',
      'showLabel' => '',
      'showCount' => TRUE,
      'showReset' => FALSE,
      'resetText' => 'Reset (@count)',
      'collapsible' => FALSE,
      'closed' => FALSE,
      'showCountInCollapseLabel' => FALSE,
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function blockForm($form, FormStateInterface $form_state): array {
    $form['key'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Facet to display'),
      '#description' => $this->t('Machine name of the facet to display'),
      '#default_value' => $this->configuration['key'],
    ];
    $form['overrideLabel'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Override the facet label'),
      '#default_value' => $this->configuration['overrideLabel'],
    ];
    $form['showLabel'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Show the facet label'),
      '#default_value' => $this->configuration['showLabel'],
    ];
    $form['showCount'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Show count'),
      '#default_value' => $this->configuration['showCount'],
    ];
    $form['showReset'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Show reset button in facet'),
      '#default_value' => $this->configuration['showReset'],
    ];
    $form['resetText'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Rest text'),
      '#description' => $this->t('The label to use for the reset/clear facet selection button. `@count` can be used as a token that will be replaced with the number of selected options.'),
      '#default_value' => $this->configuration['resetText'],
    ];
    $form['collapsible'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Collapsible'),
      '#default_value' => $this->configuration['collapsible'],
    ];
    $form['closed'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Close collapsible facet by default'),
      '#default_value' => $this->configuration['closed'],
    ];
    $form['showCountInCollapseLabel'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Show applied options count in collapsible facet label'),
      '#default_value' => $this->configuration['showCountInCollapseLabel'],
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function blockSubmit($form, FormStateInterface $form_state): void {
    $this->configuration['key'] = $form_state->getValue('key');
    $this->configuration['overrideLabel'] = $form_state->getValue('overrideLabel');
    $this->configuration['showLabel'] = $form_state->getValue('showLabel');
    $this->configuration['showCount'] = $form_state->getValue('showCount');
    $this->configuration['showReset'] = $form_state->getValue('showReset');
    $this->configuration['resetText'] = $form_state->getValue('resetText');
    $this->configuration['collapsible'] = $form_state->getValue('collapsible');
    $this->configuration['closed'] = $form_state->getValue('closed');
    $this->configuration['showCountInCollapseLabel'] = $form_state->getValue('showCountInCollapseLabel');
  }

  /**
   * {@inheritdoc}
   */
  public function build(): array {
    return [
      '#key' => $this->configuration['key'],
      '#overrideLabel' => $this->configuration['overrideLabel'],
      '#showLabel' => $this->configuration['showLabel'],
      '#showCount' => $this->configuration['showCount'],
      '#showReset' => $this->configuration['showReset'],
      '#resetText' => $this->configuration['resetText'],
      '#collapsible' => $this->configuration['collapsible'],
      '#closed' => $this->configuration['closed'],
      '#showCountInCollapseLabel' => $this->configuration['showCountInCollapseLabel'],
      '#attached' => [
        'library' => [
          'search_web_components/components',
        ],
      ],
    ];
  }

}
