<?php

declare(strict_types = 1);

namespace Drupal\search_web_components_block\Plugin\Block;

use Drupal\Core\Form\FormStateInterface;

/**
 * Provides a search component: facet checkbox.
 *
 * @Block(
 *   id = "swc_facet_checkbox",
 *   admin_label = @Translation("Facet: Checkbox"),
 *   category = @Translation("Search Components"),
 * )
 */
final class FacetCheckboxBlock extends FacetBlockBase {

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration(): array {
    return parent::defaultConfiguration() + [
      'useRadios' => FALSE,
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function blockForm($form, FormStateInterface $form_state): array {
    $form = parent::blockForm($form, $form_state);
    $form['useRadios'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Use radio inputs'),
      '#default_value' => $this->configuration['useRadios'],
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function blockSubmit($form, FormStateInterface $form_state): void {
    parent::blockSubmit($form, $form_state);
    $this->configuration['useRadios'] = $form_state->getValue('useRadios');
  }

  /**
   * {@inheritdoc}
   */
  public function build(): array {
    $build = parent::build();
    $build['#theme'] = 'swc_facet_checkbox';
    $build['#useRadios'] = $this->configuration['useRadios'];

    return $build;
  }

}
