<?php

declare(strict_types = 1);

namespace Drupal\search_web_components_block\Plugin\Block;

use Drupal\Core\Form\FormStateInterface;

/**
 * Provides a search component: facet dropdown.
 *
 * @Block(
 *   id = "swc_facet_dropdown",
 *   admin_label = @Translation("Facet: Dropdown"),
 *   category = @Translation("Search Components"),
 * )
 */
final class FacetDropdownBlock extends FacetBlockBase {

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration(): array {
    return parent::defaultConfiguration() + [
      'selectLabel' => 'Choose an option',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function blockForm($form, FormStateInterface $form_state): array {
    $form = parent::blockForm($form, $form_state);
    $form['selectLabel'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Select label'),
      '#description' => $this->t('The label text to display inside the select box.'),
      '#default_value' => $this->configuration['selectLabel'],
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function blockSubmit($form, FormStateInterface $form_state): void {
    parent::blockSubmit($form, $form_state);
    $this->configuration['selectLabel'] = $form_state->getValue('selectLabel');
  }

  /**
   * {@inheritdoc}
   */
  public function build(): array {
    $build = parent::build();
    $build['#theme'] = 'swc_facet_dropdown';
    $build['#selectLabel'] = $this->configuration['selectLabel'];

    return $build;
  }

}
