<?php

declare(strict_types = 1);

namespace Drupal\search_web_components_block\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Provides a search component: input block.
 *
 * @Block(
 *   id = "swc_search_results",
 *   admin_label = @Translation("Results"),
 *   category = @Translation("Search Components"),
 * )
 */
final class SearchResultsBlock extends BlockBase {

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration(): array {
    return [
      'elementMap' => '{"default":"search-result-element-default"}',
      'elementProp' => '',
      'settings' => '',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function blockForm($form, FormStateInterface $form_state): array {
    $form['elementMap'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Element mapping'),
      '#description' => $this->t("A JSON object to use for mapping results to elements. I.e. {\"node-page\":\"search-node-page-result\"}. The 'default' property mapping is used if there is no other match for the result type. The display key can be appended to use different mappings per result display. I.e. `node-page-grid`. Tools like <a href='https://jsonformatter.org/' target='_blank'>https://jsonformatter.org/</a>a can help validate your JSON."),
      '#default_value' => $this->configuration['elementMap'],
    ];
    $form['elementProp'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Result prop'),
      '#description' => $this->t('The property in a result that should be used to map to an element'),
      '#default_value' => $this->configuration['elementProp'],
    ];
    $form['settings'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Element settings'),
      '#description' => $this->t("A JSON object of settings for each result type. I.e. {\"node-page\":{\"someSetting\":\"someValue\"}}. The 'default' property mapping is used if there is no other match for the result type. The display key can be appended to use different settings per result display. I.e. `node-page-grid`. Tools like <a href='https://jsonformatter.org/' target='_blank'>https://jsonformatter.org/</a>a can help validate your JSON."),
      '#default_value' => $this->configuration['settings'],
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function blockSubmit($form, FormStateInterface $form_state): void {
    $this->configuration['elementMap'] = $form_state->getValue('elementMap');
    $this->configuration['elementProp'] = $form_state->getValue('elementProp');
    $this->configuration['settings'] = $form_state->getValue('settings');
  }

  /**
   * {@inheritdoc}
   */
  public function build(): array {
    return [
      '#theme' => 'swc_search_results',
      '#elementMap' => $this->configuration['elementMap'],
      '#elementProp' => $this->configuration['elementProp'],
      '#settings' => $this->configuration['settings'],
      '#attached' => [
        'library' => [
          'search_web_components/components',
        ],
      ],
    ];
  }

}
