<?php

namespace Drupal\search_web_components_layout\Plugin\Layout;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Layout\LayoutDefault;
use Drupal\Core\Plugin\PluginFormInterface;
use Drupal\Core\Template\Attribute;

/**
 * Configurable one column layout plugin class.
 *
 * @internal
 *   Plugin classes are internal.
 */
class OneColumn extends LayoutDefault implements PluginFormInterface {

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    $configuration = parent::defaultConfiguration();
    return $configuration + [
      'url' => '',
      'defaultPerPage' => '10',
      'defaultResultDisplay' => 'list',
      'updateUrl' => TRUE,
      'additionalParams' => '',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    $form['url'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Decoupled Search Endpoint URL'),
      '#default_value' => $this->configuration['url'],
      '#description' => $this->t('The url for the endpoint to use for this search.Usually /api/search/{search_endpoint_name}. Initial search query parameters can be added to this url. Search query params added to this url will be used for the initial search if no search query params are present in the page url, they will also be added to the page url on search load, and can be removed by components.'),
    ];

    $form['additionalParams'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Additional search params'),
      '#default_value' => $this->configuration['additionalParams'],
      '#description' => $this->t("A valid search query parameter string starting with '?'. These parameters will be added to all searches but will not be added to the page url."),
    ];

    $form['defaultPerPage'] = [
      '#type' => 'number',
      '#title' => $this->t('Default results per page'),
      '#default_value' => $this->configuration['defaultPerPage'],
      '#description' => $this->t('The default number of results to show per page.'),
    ];

    $form['defaultResultDisplay'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Default result display'),
      '#default_value' => $this->configuration['defaultResultDisplay'],
    ];

    $form['updateUrl'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Update the page url with parameters from the search'),
      '#default_value' => $this->configuration['updateUrl'],
    ];
    return parent::buildConfigurationForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitConfigurationForm(array &$form, FormStateInterface $form_state) {
    parent::submitConfigurationForm($form, $form_state);
    $this->configuration['url'] = $form_state->getValue('url');
    $this->configuration['defaultPerPage'] = $form_state->getValue('defaultPerPage');
    $this->configuration['defaultResultDisplay'] = $form_state->getValue('defaultResultDisplay');
    $this->configuration['updateUrl'] = $form_state->getValue('updateUrl');
    $this->configuration['additionalParams'] = $form_state->getValue('additionalParams');
  }

  /**
   * {@inheritdoc}
   */
  public function build(array $regions) {
    $build = parent::build($regions);
    $build['#settings']['search_root_attributes'] = new Attribute([
      'url' => $this->configuration['url'],
      'defaultPerPage' => $this->configuration['defaultPerPage'],
      'defaultResultDisplay' => $this->configuration['defaultResultDisplay'],
    ]);

    if (!$this->configuration['updateUrl']) {
      $build['#settings']['search_root_attributes']['noPageUrlUpdate'] = !$this->configuration['updateUrl'];
    }

    if ($this->configuration['additionalParams']) {
      $build['#settings']['search_root_attributes']['additionalParams'] = !$this->configuration['additionalParams'];
    }

    return $build;
  }

}
